Registration | OiRA

Topics

# Registration

## Why do I have to register?

The first thing you will be asked to do when you begin your first risk assessment is to create an OiRA account - this is a simple and quick process.

Registering allows you to log in at any time to access your data, continue previous assessments or to start new ones.

Through your registration the OiRA system can save all your sessions and you will always have your data available.

Find here more information about how we deal with your personal data!

## What is the difference between a registered user and a test session?

A test session is meant for interested parties to have a look at the tool before deciding to register. However, during a test session your data is not saved, and you will not be able to retrieve any entered information at a later point. Besides, a test session does not allow you to print any of the reports, whereas registering your account allows you to document your risk assessment.

## Register for a new account

Is this your first visit? Follow these simple steps to get started:

1.) Click on “Register” to view the registration form

Registration form.

2.) Enter your e-mail address and choose a password (twice)

3.) Click “Next” to register your new account

4.) Read and accept the privacy policy to continue

You will be logged in directly to the OiRA system.

## Logging in to an existing account

If you have registered already, this is how you can access your account.

1.) Visit the login form. A link to the login form will be shown to you whenever you try to access OiRA, until you have logged in.

Login form.

2.) Insert your e-mail address and your password

3.) Sign in by clicking the button “Login” Once you are logged in, you will see the screen below. From here you can start a new risk assessment or enter risk assessments that you have started before.

The dashboard.

Start a new risk assessment by giving it a title (for example Mycompany 2010-07-03) or access one of your former risk assessments. All your risk assessments are saved for future reference unless you choose to delete them.

Scroll to top
Back

## 1-registration.md

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search